Appellate 4th

Supreme Court of the State of New York
APPELLATE DIVISION

Fourth Judicial Department

Welcome
Home
THE COURT
Overview of the Appellate Division
Justices of the Court
The Courthouse
DECISIONS
Latest Decisions
Decision Release Dates
Search
CLERKS OFFICE
Clerk and Deputy Clerk of the Court
Contact Information
Terms of the Court
Court Calendars
Rules of Practice
Frequently Asked Questions
Forms and Practice Aids
Latest Court News
Employment Opportunities
ATTORNEY MATTERS
Admission to the Bar
Attorney Discipline
Attorney Registration Delinquency
Registration as In-House Counsel
Retirement
Voluntary Resignation
PROGRAMS & AUXILIARY AGENCIES
Assigned Counsel Program
Attorneys for Children Program
Attorney Grievance Committees
Court Examiners
Indep. Judicial Election Qual. Comm.
Law Library
Mental Hygiene Legal Service
Pro Bono Policy and Program
RELATED LINKS
Court sites
Legal sites

Decisions - July 3, 2014

BARNES, JAKOTA W., PEOPLE v | 800 | KA 12-02113 | (I2009-1983)
BISH, ROBERT v ODELL FARMS PARTNERSHIP, | 568 | CA 13-01811 | (K12012-87)
BOEKHOUT, JR., BARRY, PEOPLE v | 797 | KA 13-01684 | (I12-132)
BOGGS, TEMPLE, PEOPLE v | 743 | KA 09-02091 | (I2008-1022)
BONACCI, JAMES M., PEOPLE v | 651 | KA 11-01221 | (I2009-0736)
BRINSON, DEONTE J., PEOPLE v | 804 | KA 13-01549 | (I2012-010A)
BROCKINGTON, GERALD v FISCHER, BRIAN | 793 | CA 13-00403 | (21,272-12)
BROWN, GEORGE v ANNUCCI, ANTHONY | 795 | TP 14-00004 | (21404-13)
CASTRO, JUAN, PEOPLE v | 810 | KA 12-01867 | (I2011-0126)
DALLAS, RICHARD, PEOPLE v | 767 | KA 12-02311 | (I11-149)
DAVIS, LATEEK, PEOPLE v | 826 | KA 13-00651 | (I2012-160)
DAVIS, LATEEK, PEOPLE v | 827 | KA 13-00653 | (I2012-161)
DIMOND, FREDERICK v TIME WARNER, INC., | 510 | CA 13-01817 | (40559)
DOMINICCI, LIMARIE v FORD, THOMAS | 748 | CA 13-02097 | (2011-3585)
EAST, JR., RONALD, PEOPLE v | 787 | KA 13-01844 | (I2012-00891)
ERON, CHRISTOPHER H., PEOPLE v | 746 | KA 12-01694 | (I02528-2011)
FARRUGGIA, GAETANO v TOWN OF PENFIELD, | 201 | CA 13-01562 | (2011-8731)
FERRUSI, MELISSA A. v JAMES, SHARIFF K. | 813 | CAF 13-01036 | (O-01079-11/12B)
FERRUSI, MELISSA A. v JAMES, SHARIFF K. | 814 | CAF 13-01037 | (O-01079-11/12B)
FOOTS, JAMES v CONSOLIDATED BUILDING CONTRACTORS,, | 309 | CA 13-01437 | (2008-06153)
GARRETT, JERRY v ANNUCCI, ANTHONY | 815 | TP 14-00108 | (21,409-13)
GREEN, DAVID v BLASKIEWICZ, M.D., DONALD J. | 777 | CA 13-01005 | (2010-7307)
GUARIGLIA, MICHAEL A., PEOPLE v | 681 | KA 13-02182 | (2011-262)
HALL, BRANDON S., PEOPLE v | 657 | KA 09-00861 | (I2008-0616D)
HENSON, ROGER v CITY OF SYRACUSE, | 569 | CA 13-01812 | (2012-6455)
HORNING, THOMAS E. v MORGIA, ANDREA J. | 705 | CAF 13-00134 | (V-01336-04/11U)
HOUGHTON, JR., KENNETH W., PEOPLE v | 828 | KA 13-00829 | (S2012-546)
JACKSON, CONSTANTINE v ANNUCCI, ANTHONY | 824 | TP 14-00134 | (21,368-13)
JACKSON, DEJUAN D., PEOPLE v | 762 | KA 12-01703 | (S02106-2011)
JACKSON, TOMMY R., PEOPLE v | 627 | KA 11-01145 | (I2006-0989-1)
JOHNSON, KEVIN C., PEOPLE v | 785 | KA 13-01142 | (I5572)
KESICK, RICHARD P., PEOPLE v | 788 | KA 13-00201 | (I2012-01544)
KINDRED, DENNIS H. v MONROE COUNTY, | 640 | CA 13-01718 | (2013/06517)
KOLATA, DANIEL J., PEOPLE v | 809 | KA 13-01147 | (I12-163)
KUMAR, RAVI v FISCHER, BRIAN | 792 | CA 13-00905 | (21,308-13)
MALONE, TYRONE L., PEOPLE v | 696 | KA 10-01760 | (I2009-0082)
MARCHIONDA, STEVEN v INDUSTRIAL BD OF APPEALS OF STATE, | 593 | TP 13-02121 | (13/10747)
MARRERO, MARGARET D., PEOPLE v | 819 | KA 13-00251 | (I12-04-068B)
MARTIN, JON C., PEOPLE v | 830 | KA 13-00801 | (ITOS-1006)
MCFADDEN, STEVON v FISCHER, BRIAN | 802 | CA 13-00915 | (21,315-13)
MCKETHAN, WILLIAM v STALLONE, DAVID | 784 | TP 14-00101 | (2013-1056)
MORGIA, ANDREA J. v HORNING, THOMAS E. | 704 | CAF 13-00133 | (V-01336-04/10R)
MORGIA, ANDREA J. v HORNING, THOMAS E. | 706 | CAF 13-00135 | (V-01336-04/11T)
MORGIA, ANDREA J. v HORNING, THOMAS E. | 707 | CAF 13-00136 | (V-01336-04/11S)
NUNEZ, MELISA, PEOPLE v | 799 | KA 13-01194 | (I13-01)
OLIVER, WILLIAM P., PEOPLE v | 820 | KA 12-01918 | (I2012-074)
PAYNE, BERTRAM v STATE OF NEW YORK, | 801 | CA 13-01081 | (115204)
PENABLE, GABRIEL v FISCHER, BRIAN | 790 | CA 13-00936 | (21,310-13)
POLEUN, JAMES R., PEOPLE v | 812 | KA 13-01143 | (S2008-328)
ROBINSON, CHRISTOPHER E., PEOPLE v | 817 | KA 13-01181 | (SI-13-496-12)
RUIZ, CHALINA v COPE, BRENDAN L. | 547 | CA 13-00383 | (2007-4561)
SCOTT, ROBERT D., PEOPLE v | 831 | KA 13-01178 | (I4558)
SIMMONS, SAMUEL CARL, PEOPLE v | 609 | KA 12-01628 | (I01562X-2010)
STATE OF NEW YORK, v BASS, MICHAEL C. | 740 | CA 13-00211 | (MH7303)
STEELE, WILLIAM v ANNUCCI, ANTHONY | 816 | TP 14-00287 | (21,428-13)
SULLIVAN, DARREN, PEOPLE v | 557 | KA 12-01763 | (I11-07-108)
VAL TECH HOLDINGS, INC., v WILSON MANIFOLDS, INC., | 395 | CA 13-00949 | (2009/11206)
WILLIAMS, APRIL M. v FASSINGER, CHARLES A. | 779 | CA 13-01790 | (2010-2439)
WILLIAMS, CASSONDRA v COUNTY OF ERIE, | 625 | CA 13-01671 | (I2010-006636)
WILLIAMS, APRIL M. v FASSINGER, CHARLES A. | 780 | CA 13-01791 | (2010-2439)
WRIGHT, STANLEY, PEOPLE v | 829 | KA 11-00853 | (I2010-0971-1)
Motions and Crawfords |  |  |